# pyJustpyWidgets
Widgets and demo for [Justpy](https://justpy.io/)

[![pypi](https://img.shields.io/pypi/pyversions/pyJustpyWidgets)](https://pypi.org/project/pyJustpyWidgets/)
[![Github Actions Build](https://github.com/WolfgangFahl/pyJustpyWidgets/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/pyJustpyWidgets/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/pyJustpyWidgets.svg)](https://pypi.python.org/pypi/pyJustpyWidgets/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyJustpyWidgets.svg)](https://github.com/WolfgangFahl/pyJustpyWidgets/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyJustpyWidgets.svg)](https://github.com/WolfgangFahl/pyJustpyWidgets/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/pyJustpyWidgets.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/pyJustpyWidgets)

## Demo
[Demo](http://jpdemo.bitplan.com)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
* Tim Holzheim
